@@ -46,7 +46,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.5.2"
+VERSION = "0.5.3"
 LOCK_SH = 0
 LOCK_EX = 1
 
@@ -259,13 +259,13 @@ class StarryDepot(object):
 
             self.backup()
 
-        self.database.joinpath(".starry").write_bytes(msgpack.packb(server))
+        self.database.joinpath(".starrydb").write_bytes(msgpack.packb(server))
 
     def __del__(self):
         self.clearCache()
 
         try:
-            self.database.joinpath(".starry").unlink()
+            self.database.joinpath(".starrydb").unlink()
         except:
             pass
 
@@ -322,16 +322,16 @@ class StarryDepot(object):
     def setCache(self, cache_size):
         if int(cache_size) > 0:
             try:
-                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starry').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
+                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starrydb').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
             except:
                 pass
 
             try:
-                os.system(f"memcached -d -u root -a 0777 -D : -C -m {int(cache_size)} -s {str(self.database.joinpath('cache.starry').resolve())}")
+                os.system(f"memcached -d -u root -a 0777 -D : -C -m {int(cache_size)} -s {str(self.database.joinpath('cache.starrydb').resolve())}")
 
                 time.sleep(1)
 
-                self.cache = LibMemcachedClient(str(self.database.joinpath('cache.starry').resolve()))
+                self.cache = LibMemcachedClient(str(self.database.joinpath('cache.starrydb').resolve()))
             except Exception as e:
                 self.logger.error(f"Caught exception: {e.__doc__}({e})")
 
@@ -347,7 +347,7 @@ class StarryDepot(object):
                 pass
 
             try:
-                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starry').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
+                subprocess.check_output(f"fuser -k {str(self.database.joinpath('cache.starrydb').resolve())}", shell=True, stderr=subprocess.STDOUT, universal_newlines=True)
             except:
                 pass
 
@@ -427,25 +427,10 @@ class StarryDepot(object):
             (ret, _) = self._get(key)
             return (True, ret)
 
-    def getMultiList(self, keys):
-        values = []
-
-        mark = {"mode": "r", "members": keys}
-
-        with self._lock(mark):
-            for key in keys:
-                (ret, value) = self._get([key])
-                if ret is False:
-                    return (ret, value)
-
-                values.append(value)
-
-            return (True, values)
-
-    def getMultiDict(self, keys):
+    def getMulti(self, keys):
         values = {}
 
-        mark = {"mode": "r", "members": keys}
+        mark = {"mode": "r", "members": list(keys)}
 
         with self._lock(mark):
             for key in keys:
@@ -704,7 +689,7 @@ class StarryDepot(object):
         if len(branch) > 0:
             (ret, value) = _getPart(value, branch, filters)
             if ret is False:
-                return (False, f'Can not find {"~".join(branch)} in {key}.')
+                return (False, f'Can not find {".".join(branch)} in {key}.')
 
         return (True, value)
 
@@ -1082,7 +1067,7 @@ class StarryDepot(object):
 class StarryClient(object):
     def __init__(self, path, mode=LOCK_SH, address=None):
         if address is None:
-            address = msgpack.unpackb(pathlib.Path(os.path.join(path, ".starry")).read_bytes(), use_list=False)
+            address = msgpack.unpackb(pathlib.Path(os.path.join(path, ".starrydb")).read_bytes(), use_list=False)
 
         self.client = multiprocessing.connection.Client(address, authkey=b'starry')
         self.client.send((os.path.abspath(path), mode))
@@ -1161,11 +1146,8 @@ class StarryClient(object):
     def clear(self):
         return self._callableForward("clear")
 
-    def getMultiList(self, keys):
-        return self._callableForward("getMultiList", keys)
-
-    def getMultiDict(self, keys):
-        return self._callableForward("getMultiDict", keys)
+    def getMulti(self, keys):
+        return self._callableForward("getMulti", keys)
 
     def getAll(self):
         return self._callableForward("getAll")
